import { useState } from 'react';
import { 
  Shield, 
  Server, 
  Cloud,
  FileText,
  CheckSquare,
  ClipboardList,
  UserPlus,
  Phone, 
  Mail, 
  MapPin, 
  CheckCircle, 
  Star,
  ArrowRight,
  Monitor,
  Lock,
  Headphones,
  Building,
  Users,
  Award,
  Clock,
  TrendingUp,
  AlertTriangle,
  Globe,
  Zap,
  HelpCircle,
  Plus,
  Minus,
  Laptop,
  RefreshCw,
  Briefcase
} from 'lucide-react';
import { Link } from 'react-router-dom';

export default function Home() {
  const [formData, setFormData] = useState<{
    name: string;
    email: string;
    phone: string;
    message: string;
  }>({
    name: '',
    email: '',
    phone: '',
    message: ''
  });

  const [openFAQ, setOpenFAQ] = useState<number | null>(null);

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    setFormData({
      ...formData,
      [e.target.name]: e.target.value
    });
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    console.log('Form submitted:', formData);
    
    // Create FormData object for Netlify
    const form = e.target as HTMLFormElement; 
    const formDataToSend = new FormData(form);
    
    // Submit the form data to Netlify
    fetch("/", {
      method: "POST",
      headers: { "Content-Type": "application/x-www-form-urlencoded" },
      body: new URLSearchParams(formDataToSend as any).toString(),
    })
      .then(() => {
        alert('Thank you for your interest! We\'ll contact you within 24 hours.');
        setFormData({ name: '', email: '', phone: '', message: '' });
      })
      .catch((error) => {
        console.error("Form submission error:", error);
        alert('There was an error submitting the form. Please try again later.');
      });
  };

  const toggleFAQ = (index: number) => {
    setOpenFAQ(openFAQ === index ? null : index);
  };

  const faqs = [
    {
      question: "What managed IT services do you provide for Miami businesses?",
      answer: "We offer comprehensive managed IT services including monitoring and support, cybersecurity protection, cloud solutions, network management, data backup and recovery, IT consulting, and Microsoft 365 services. Our services are designed to keep your Miami business running smoothly while reducing IT costs and improving efficiency."
    },
    {
      question: "How quickly can you respond to IT emergencies in Miami?",
      answer: "We provide emergency support for critical IT issues during business hours and offer emergency support. Our local Miami technicians can be on-site within 2 hours for urgent situations. We understand that downtime costs money, so we prioritize rapid response and resolution."
    },
    {
      question: "Do you serve all areas of Miami-Dade County?",
      answer: "Yes, we provide IT services throughout Miami-Dade County including Downtown Miami, Brickell, Coral Gables, Coconut Grove, South Beach, Aventura, Doral, Hialeah, Homestead, Kendall, Miami Lakes, Wynwood, and all surrounding areas. We have local technicians strategically located for fast response times."
    },
    {
      question: "What cybersecurity measures do you implement for Miami businesses?",
      answer: "Our cybersecurity services include advanced threat protection, 24/7 security monitoring, firewall management, endpoint protection, email security, employee training, vulnerability assessments, and compliance management (HIPAA, SOX, PCI DSS). We protect against ransomware, phishing, and other cyber threats targeting Miami businesses."
    },
    {
      question: "How much do your managed IT services cost?",
      answer: "Our pricing is customized based on your specific needs, company size, and required services. We offer transparent, flat-rate monthly pricing with no hidden fees. Most Miami businesses save 30-50% compared to hiring in-house IT staff. Contact us for a free assessment and customized quote."
    },
    {
      question: "Can you help migrate our business to the cloud?",
      answer: "Absolutely! We specialize in cloud migration for Miami businesses, including Office 365, Microsoft Azure, Amazon AWS, and Google Cloud. We handle everything from planning and migration to ongoing management and optimization. Our cloud solutions improve accessibility, security, and scalability while reducing costs."
    },
    {
      question: "Do you provide IT support for specific industries in Miami?",
      answer: "Yes, we have specialized experience serving healthcare practices (HIPAA compliance), legal firms (attorney-client privilege protection), financial services (SOX compliance), hospitality businesses (PCI DSS), manufacturing companies, and professional services. We understand industry-specific requirements and regulations."
    },
    {
      question: "What happens if our current IT provider isn't meeting our needs?",
      answer: "We make switching IT providers seamless and stress-free. We'll assess your current setup, identify issues, and create a transition plan with zero downtime. Many Miami businesses switch to us for better service, faster response times, and more proactive support. We handle all the technical details of the transition."
    },
    {
      question: "How do you ensure our business data is protected and backed up?",
      answer: "We implement comprehensive data protection including automated daily backups, cloud storage with encryption, local backup appliances, disaster recovery planning, and regular backup testing. Your data is protected both on-site and off-site with multiple recovery options to ensure business continuity."
    },
    {
      question: "What makes your IT company different from others in Miami?",
      answer: "We're locally owned and operated with 15+ years serving Miami businesses. Our differentiators include proactive monitoring that prevents 99% of issues, transparent pricing, Microsoft and security certifications, bilingual support, and deep understanding of Miami's business environment including hurricane preparedness."
    },
    {
      question: "How do you handle hurricane season and natural disaster preparedness for Miami businesses?",
      answer: "Living in Miami means preparing for hurricane season every year. We provide comprehensive disaster recovery planning including off-site data backups, cloud-based systems that can be accessed remotely, emergency communication plans, and rapid recovery procedures. Our team has extensive experience helping Miami businesses maintain operations during and after hurricanes."
    },
    {
      question: "Do you offer bilingual IT support for Miami's diverse business community?",
      answer: "Yes, we provide bilingual IT support in both English and Spanish to serve Miami's diverse business community. Our technicians can communicate effectively with all team members, ensuring clear understanding of technical issues and solutions. This is especially important for family-owned businesses and companies with multilingual staff."
    },
    {
      question: "Can you help us achieve compliance with industry regulations like HIPAA or PCI DSS?",
      answer: "Absolutely. We specialize in helping Miami businesses achieve and maintain compliance with various industry regulations including HIPAA for healthcare, PCI DSS for businesses processing credit cards, SOX for financial services, and other regulatory requirements. We provide compliance assessments, implementation, ongoing monitoring, and audit support."
    },
    {
      question: "What is your process for onboarding new clients and assessing our current IT infrastructure?",
      answer: "Our onboarding process begins with a comprehensive IT assessment where we evaluate your current systems, identify vulnerabilities, and document your infrastructure. We then create a customized improvement plan with priorities and timelines. The transition is carefully managed to ensure zero downtime, and we provide training for your team on any new systems or processes."
    },
    {
      question: "How do you stay current with the latest technology trends and security threats?",
      answer: "Our team maintains current certifications from Microsoft, Cisco, and leading security vendors. We continuously monitor threat intelligence feeds, participate in industry training, and invest in the latest security tools and technologies. This ensures we can protect Miami businesses against emerging threats and recommend cutting-edge solutions that provide competitive advantages."
    }
  ];

  return (
    <>
      {/* Hero Section */}
      <section className="hero-section">
        {/* Background Image */}
        <div 
          className="absolute inset-0 bg-cover bg-center bg-no-repeat"
          style={{
            backgroundImage: 'url(https://images.pexels.com/photos/1181467/pexels-photo-1181467.jpeg?auto=compress&cs=tinysrgb&w=1920&h=1080&fit=crop)',
          }}
        >
          <div className="absolute inset-0 bg-gradient-to-br from-blue-900/90 via-blue-800/85 to-indigo-900/90"></div>
        </div>
        
        {/* Content */}
        <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <h1 className="text-4xl lg:text-6xl font-bold text-white mb-6 leading-tight">
                Best Managed IT Services in Miami for Any Business
              </h1>
              <p className="text-xl text-blue-100 mb-6 leading-relaxed">
                Keep your business running smoothly with our <strong>managed IT services in Miami</strong>. From cybersecurity to cloud solutions, we've got Miami businesses covered. Our expert team provides 24/7 monitoring and proactive support to prevent downtime and maximize productivity.
              </p>
              <p className="text-lg text-blue-100 mb-8 leading-relaxed">
                Serving all of Miami-Dade County including Brickell, Downtown Miami, Coral Gables, Doral, and South Beach with enterprise-grade IT solutions tailored for businesses of all sizes.
              </p>
              <div className="flex flex-col sm:flex-row gap-4 justify-center lg:justify-start">
                <a href="tel:3058423363" className="bg-blue-600 text-white px-8 py-4 rounded-lg text-lg font-semibold hover:bg-blue-700 transition-all transform hover:scale-105 shadow-lg flex items-center justify-center">
                  <Phone className="mr-2 h-5 w-5" />
                  Call (305) 842-3363
                </a>
                <a href="#contact" className="border-2 border-white text-white px-8 py-4 rounded-lg text-lg font-semibold hover:bg-white hover:text-blue-600 transition-all flex items-center justify-center">
                  Contact Us
                </a>
              </div>
              
              {/* Trust Indicators */}
              <div className="mt-8 flex flex-wrap items-center justify-center lg:justify-start gap-6">
                <div className="flex items-center">
                  <Award className="h-6 w-6 text-yellow-400 mr-2" />
                  <span className="text-sm text-blue-100">Microsoft Certified</span>
                </div>
                <div className="flex items-center">
                  <Shield className="h-6 w-6 text-green-400 mr-2" />
                  <span className="text-sm text-blue-100">SOC 2 Compliant</span>
                </div>
                <div className="flex items-center">
                  <Clock className="h-6 w-6 text-blue-300 mr-2" />
                  <span className="text-sm text-blue-100">24/7 Support</span>
                </div>
              </div>
            </div>
            
            <div className="relative">
              <div className="bg-white/95 backdrop-blur-sm rounded-2xl shadow-2xl p-8">
                <h3 className="text-2xl font-bold text-gray-900 mb-6">Contact Us</h3>
                <form 
                  onSubmit={handleSubmit} 
                  className="space-y-4"
                  name="contact"
                  method="POST"
                  data-netlify="true"
                >
                  <input type="hidden" name="form-name" value="contact" />
                  <input
                    type="text"
                    name="name"
                    placeholder="Name"
                    value={formData.name}
                    onChange={handleInputChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                  <input
                    type="email"
                    name="email"
                    placeholder="Email Address"
                    value={formData.email}
                    onChange={handleInputChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                  <input
                    type="tel"
                    name="phone"
                    placeholder="Phone Number"
                    value={formData.phone}
                    onChange={handleInputChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                  <textarea
                    name="message"
                    placeholder="Tell us about your IT needs..."
                    value={formData.message}
                    onChange={handleInputChange}
                    rows={4}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                  <button
                    type="submit"
                    className="w-full bg-green-600 text-white py-3 rounded-lg font-semibold hover:bg-green-700 transition-colors"
                  >
                    Send Message
                  </button>
                </form>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Services Section */}
      <section id="services" className="section-padding bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Complete IT Solutions for Miami Businesses
            </h2>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto mb-4">
              From startups to enterprises, we provide comprehensive IT services that keep your Miami business secure, efficient, and growing.
            </p>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto">
              Our team of certified IT professionals brings over 15 years of experience serving South Florida's unique business needs, including hurricane preparedness, multilingual support, and industry-specific compliance requirements.
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
            {[
              {
                icon: <Monitor className="h-12 w-12 text-blue-600" />,
                title: "Managed IT Services",
                description: "Complete technology management with 24/7 monitoring, support, and maintenance for your entire IT infrastructure.",
                link: "/services/managed-it-services"
              },
              {
                icon: <Shield className="h-12 w-12 text-green-600" />,
                title: "Cybersecurity",
                description: "Advanced threat protection, security audits, and compliance management to protect your valuable business data.",
                link: "/services/cybersecurity-services"
              },
              {
                icon: <Cloud className="h-12 w-12 text-purple-600" />,
                title: "Cloud Solutions",
                description: "Seamless cloud migration, management, and optimization. Reduce costs while improving accessibility and security.",
                link: "/services/cloud-solutions"
              },
              {
                icon: <Headphones className="h-12 w-12 text-orange-600" />,
                title: "24/7 IT Support",
                description: "Round-the-clock monitoring and support to keep your systems running smoothly. Average response time under 15 minutes.",
                link: "/services/it-support"
              },
              {
                icon: <Lock className="h-12 w-12 text-red-600" />,
                title: "Data Backup & Recovery",
                description: "Comprehensive backup solutions with quick recovery options. Your data is safe with our proven systems.",
                link: "/services/data-backup-recovery"
              },
              {
                icon: <Zap className="h-12 w-12 text-yellow-600" />,
                title: "IT Consulting",
                description: "Strategic IT planning and consulting to align technology with your business goals and drive growth.",
                link: "/services/it-consulting"
              },
              {
                icon: <Server className="h-12 w-12 text-indigo-600" />,
                title: "Network Management",
                description: "Robust network infrastructure design, implementation, and ongoing management for optimal performance.",
                link: "/services/network-management"
              },
              {
                icon: <Mail className="h-12 w-12 text-red-600" />,
                title: "Email Security",
                description: "Advanced email protection against phishing, malware, and business email compromise attacks.",
                link: "/services/email-security"
              },
              {
                icon: <Phone className="h-12 w-12 text-purple-600" />,
                title: "VoIP Services",
                description: "Modern business phone systems with advanced features for seamless communication anywhere.",
                link: "/services/voip-services"
              },
              {
                icon: <Laptop className="h-12 w-12 text-blue-600" />,
                title: "Endpoint Protection",
                description: "Comprehensive security for all your business devices against modern threats and vulnerabilities.",
                link: "/services/endpoint-protection"
              },
              {
                icon: <RefreshCw className="h-12 w-12 text-green-600" />,
                title: "Business Continuity",
                description: "Disaster recovery planning and solutions to keep your business running through any disruption.",
                link: "/services/business-continuity"
              },
              {
                icon: <Briefcase className="h-12 w-12 text-teal-600" />,
                title: "Virtual CIO Services",
                description: "Executive-level technology guidance and strategic planning without the full-time executive cost.",
                link: "/services/virtual-cio"
              },
              {
                icon: <FileText className="h-12 w-12 text-red-600" />,
                title: "IT Audit & Assessment",
                description: "Comprehensive technology evaluation and infrastructure assessment for optimal performance.",
                link: "/services/it-audit"
              },
              {
                icon: <CheckSquare className="h-12 w-12 text-amber-600" />,
                title: "IT Compliance",
                description: "Regulatory compliance management for HIPAA, PCI DSS, SOX, and other frameworks.",
                link: "/services/it-compliance"
              },
              {
                icon: <ClipboardList className="h-12 w-12 text-emerald-600" />,
                title: "IT Project Management",
                description: "Technology implementation expertise with certified project management professionals.",
                link: "/services/it-project-management"
              },
              {
                icon: <Users className="h-12 w-12 text-fuchsia-600" />,
                title: "IT Staffing",
                description: "Technical talent solutions for temporary and permanent IT positions.",
                link: "/services/it-staffing"
              }
            ].map((service, index) => (
              <Link to={service.link} key={index} className="service-card group">
                <div className="service-icon">{service.icon}</div>
                <h3 className="service-title">{service.title}</h3>
                <p className="service-description">{service.description}</p>
              </Link>
            ))}
          </div>
        </div>
      </section>

      {/* Why Choose Us Section */}
      <section id="why-choose-us" className="section-padding bg-blue-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Why Miami Businesses Choose Us
            </h2>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto mb-6">
              Trusted by over 500 businesses throughout Miami-Dade County for reliable, responsive IT support and strategic technology guidance.
            </p>
          </div>

          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <div className="space-y-6">
                {[
                  "15+ years serving Miami's business community",
                  "Proactive monitoring prevents 99% of potential problems",
                  "Certified Microsoft, Amazon AWS, and Google Cloud partner",
                  "Local team you can meet face-to-face",
                  "Transparent pricing with no hidden fees"
                ].map((benefit, index) => (
                  <div key={index} className="flex items-start">
                    <CheckCircle className="h-6 w-6 text-green-500 mr-3 mt-0.5 flex-shrink-0" />
                    <span className="text-gray-700 text-lg">{benefit}</span>
                  </div>
                ))}
              </div>
              <div className="mt-8">
                <a href="#contact" className="bg-blue-600 text-white px-8 py-4 rounded-lg text-lg font-semibold hover:bg-blue-700 transition-all transform hover:scale-105 inline-block">
                  Contact Us
                </a>
              </div>
            </div>
            
            <div className="bg-white rounded-2xl shadow-xl p-8">
              <h3 className="text-2xl font-bold text-gray-900 mb-6">Quick Stats</h3>
              <div className="grid grid-cols-2 gap-6">
                <div className="text-center">
                  <div className="text-3xl font-bold text-blue-600 mb-2">500+</div>
                  <div className="text-gray-600">Happy Clients</div>
                </div>
                <div className="text-center">
                  <div className="text-3xl font-bold text-green-600 mb-2">99.9%</div>
                  <div className="text-gray-600">Uptime SLA</div>
                </div>
                <div className="text-center">
                  <div className="text-3xl font-bold text-purple-600 mb-2">24/7</div>
                  <div className="text-gray-600">Support</div>
                </div>
                <div className="text-center">
                  <div className="text-3xl font-bold text-orange-600 mb-2">15+</div>
                  <div className="text-gray-600">Years Experience</div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Testimonials Section */}
      <section id="testimonials" className="section-padding bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              What Our Miami Clients Say
            </h2>
            <p className="text-xl text-gray-600">
              Don't take our word for it - hear from businesses just like yours
            </p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            {[
              {
                name: "Sarah Martinez",
                company: "Coral Gables Law Firm",
                rating: 5,
                text: "Managed IT Services Miami transformed our outdated systems. Their proactive approach has eliminated our IT headaches completely. We can now focus on serving our clients instead of worrying about technology."
              },
              {
                name: "Carlos Rodriguez",
                company: "Downtown Miami Restaurant Group",
                rating: 5,
                text: "When our POS system went down during lunch rush, they had us back up in 10 minutes. Their support is worth every penny. Best investment we've made for our restaurants."
              },
              {
                name: "Jennifer Kim",
                company: "Brickell Financial Services",
                rating: 5,
                text: "The cybersecurity audit they performed revealed vulnerabilities we never knew existed. Their team secured our client data and gave us peace of mind. Highly professional and knowledgeable."
              }
            ].map((testimonial, index) => (
              <div key={index} className="testimonial-card">
                <div className="testimonial-rating">
                  {[...Array(testimonial.rating)].map((_, i) => (
                    <Star key={i} className="h-5 w-5 text-yellow-400 fill-current" />
                  ))}
                </div>
                <p className="testimonial-text">"{testimonial.text}"</p>
                <div>
                  <div className="testimonial-author">{testimonial.name}</div>
                  <div className="testimonial-company">{testimonial.company}</div>
                </div>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* About Section */}
      <section id="about" className="section-padding bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-6">
                Your Local Miami IT Partners
              </h2>
              <p className="text-lg text-gray-600 mb-6 leading-relaxed">
                Founded in 2008, Managed IT Services Miami has been serving South Florida businesses with reliable, professional IT services. We understand the unique challenges facing Miami businesses, from hurricane preparedness to rapid growth management.
              </p>
              <p className="text-lg text-gray-600 mb-6 leading-relaxed">
                Our team of certified professionals combines deep technical expertise with genuine care for your business success. We're not just your IT provider - we're your technology partners, committed to helping you leverage technology for competitive advantage.
              </p>
              <p className="text-lg text-gray-600 mb-8 leading-relaxed">
                With expertise in healthcare IT compliance, financial services security, hospitality technology, and multilingual support, we're uniquely positioned to serve Miami's diverse business community. Our local presence means we understand the specific technology challenges South Florida businesses face.
              </p>
              <div className="flex items-center space-x-4">
                <div className="flex items-center">
                  <Building className="h-6 w-6 text-blue-600 mr-2" />
                  <span className="text-gray-700">Locally owned & operated</span>
                </div>
                <div className="flex items-center">
                  <Users className="h-6 w-6 text-green-600 mr-2" />
                  <span className="text-gray-700">25+ team members</span>
                </div>
              </div>
            </div>
            
            <div className="space-y-6">
              <div className="bg-white rounded-xl p-6 shadow-lg">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Our Mission</h3>
                <p className="text-gray-600">
                  To empower Miami businesses with reliable, secure, and scalable IT solutions that drive growth and success in South Florida's dynamic business environment.
                </p>
              </div>
              <div className="bg-white rounded-xl p-6 shadow-lg">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Our Promise</h3>
                <p className="text-gray-600">
                  Transparent communication, proactive service, and measurable results. Your success is our success.
                </p>
              </div>
              <div className="bg-white rounded-xl p-6 shadow-lg">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Our Commitment</h3>
                <p className="text-gray-600">
                  24/7 support, continuous learning, and staying ahead of technology trends to serve Miami businesses better. We're committed to hurricane-ready IT solutions that ensure business continuity during South Florida's storm season.
                </p>
              </div>
            </div>
          </div>
        </div>

        {/* Miami IT Services Infographic Section */}
        <section className="py-20 bg-white">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="text-center mb-12">
              <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
                Miami IT Services at a Glance
              </h2>
              <p className="text-xl text-gray-600 max-w-3xl mx-auto">
                Comprehensive technology solutions tailored for South Florida businesses
              </p>
            </div>
            
            <div className="bg-gradient-to-br from-blue-50 via-indigo-50 to-blue-50 rounded-2xl shadow-xl overflow-hidden">
              <div className="grid md:grid-cols-3 divide-y md:divide-y-0 md:divide-x divide-blue-200">
                {/* Service Coverage */}
                <div className="p-8">
                  <div className="flex items-center mb-6">
                    <div className="bg-blue-100 p-3 rounded-full mr-4">
                      <MapPin className="h-8 w-8 text-blue-600" />
                    </div>
                    <h3 className="text-xl font-bold text-gray-900">Service Coverage</h3>
                  </div>
                  <ul className="space-y-3">
                    <li className="flex items-start">
                      <CheckCircle className="h-5 w-5 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-gray-700"><strong>34 cities</strong> across Miami-Dade</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="h-5 w-5 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-gray-700"><strong>15-minute</strong> response time</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="h-5 w-5 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-gray-700"><strong>24/7/365</strong> emergency support</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="h-5 w-5 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-gray-700"><strong>On-site</strong> technicians available</span>
                    </li>
                  </ul>
                  <div className="mt-6 pt-6 border-t border-blue-200">
                    <h4 className="font-semibold text-gray-900 mb-3">Key Service Areas:</h4>
                    <div className="flex flex-wrap gap-2">
                      {["Brickell", "Downtown", "Coral Gables", "Doral", "South Beach", "Kendall", "Aventura", "Homestead"].map((area, index) => (
                        <span key={index} className="bg-blue-100 text-blue-800 px-2 py-1 rounded text-xs font-medium">
                          {area}
                        </span>
                      ))}
                    </div>
                  </div>
                </div>
                
                {/* Industry Solutions */}
                <div className="p-8">
                  <div className="flex items-center mb-6">
                    <div className="bg-indigo-100 p-3 rounded-full mr-4">
                      <Building className="h-8 w-8 text-indigo-600" />
                    </div>
                    <h3 className="text-xl font-bold text-gray-900">Industry Solutions</h3>
                  </div>
                  <div className="grid grid-cols-2 gap-4">
                    <div className="bg-white p-4 rounded-lg shadow-sm">
                      <h4 className="font-semibold text-gray-900 mb-2">Healthcare</h4>
                      <ul className="text-gray-700 text-sm space-y-1">
                        <li>• HIPAA compliance</li>
                        <li>• EMR/EHR support</li>
                        <li>• Telehealth solutions</li>
                      </ul>
                    </div>
                    <div className="bg-white p-4 rounded-lg shadow-sm">
                      <h4 className="font-semibold text-gray-900 mb-2">Financial</h4>
                      <ul className="text-gray-700 text-sm space-y-1">
                        <li>• SOC 2 compliance</li>
                        <li>• Secure infrastructure</li>
                        <li>• Trading systems</li>
                      </ul>
                    </div>
                    <div className="bg-white p-4 rounded-lg shadow-sm">
                      <h4 className="font-semibold text-gray-900 mb-2">Hospitality</h4>
                      <ul className="text-gray-700 text-sm space-y-1">
                        <li>• POS systems</li>
                        <li>• Guest WiFi</li>
                        <li>• Booking systems</li>
                      </ul>
                    </div>
                    <div className="bg-white p-4 rounded-lg shadow-sm">
                      <h4 className="font-semibold text-gray-900 mb-2">Legal</h4>
                      <ul className="text-gray-700 text-sm space-y-1">
                        <li>• Document security</li>
                        <li>• Case management</li>
                        <li>• Client confidentiality</li>
                      </ul>
                    </div>
                  </div>
                </div>
                
                {/* Business Benefits */}
                <div className="p-8">
                  <div className="flex items-center mb-6">
                    <div className="bg-green-100 p-3 rounded-full mr-4">
                      <TrendingUp className="h-8 w-8 text-green-600" />
                    </div>
                    <h3 className="text-xl font-bold text-gray-900">Business Benefits</h3>
                  </div>
                  <div className="space-y-4">
                    <div className="flex items-center">
                      <div className="w-12 h-12 bg-blue-100 rounded-full flex items-center justify-center text-blue-600 mr-4 flex-shrink-0">
                        <span className="font-bold">99.9%</span>
                      </div>
                      <div>
                        <h4 className="font-semibold text-gray-900">Uptime</h4>
                        <p className="text-sm text-gray-600">Guaranteed network reliability</p>
                      </div>
                    </div>
                    <div className="flex items-center">
                      <div className="w-12 h-12 bg-green-100 rounded-full flex items-center justify-center text-green-600 mr-4 flex-shrink-0">
                        <span className="font-bold">30%</span>
                      </div>
                      <div>
                        <h4 className="font-semibold text-gray-900">Cost Reduction</h4>
                        <p className="text-sm text-gray-600">Average IT savings</p>
                      </div>
                    </div>
                    <div className="flex items-center">
                      <div className="w-12 h-12 bg-purple-100 rounded-full flex items-center justify-center text-purple-600 mr-4 flex-shrink-0">
                        <span className="font-bold">85%</span>
                      </div>
                      <div>
                        <h4 className="font-semibold text-gray-900">Issue Reduction</h4>
                        <p className="text-sm text-gray-600">Fewer IT problems</p>
                      </div>
                    </div>
                    <div className="flex items-center">
                      <div className="w-12 h-12 bg-orange-100 rounded-full flex items-center justify-center text-orange-600 mr-4 flex-shrink-0">
                        <span className="font-bold">4hr</span>
                      </div>
                      <div>
                        <h4 className="font-semibold text-gray-900">Recovery Time</h4>
                        <p className="text-sm text-gray-600">Fast disaster recovery</p>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
              
              {/* Bottom Banner */}
              <div className="bg-gradient-to-r from-blue-600 to-indigo-600 p-6 text-white text-center">
                <p className="font-semibold">
                  Serving Miami businesses since 2008 with bilingual support and hurricane-ready IT solutions
                </p>
              </div>
            </div>
          </div>
        </section>

        {/* Miami IT Challenges Section */}
        <section className="py-20 bg-gray-50">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="text-center mb-12">
              <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
                Overcoming Miami's Unique IT Challenges
              </h2>
              <p className="text-xl text-gray-600 max-w-3xl mx-auto">
                Specialized solutions for South Florida's business technology environment
              </p>
            </div>
            
            <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
              <div className="bg-white rounded-xl shadow-md p-8 hover:shadow-lg transition-all">
                <div className="bg-red-100 w-16 h-16 rounded-full flex items-center justify-center mb-6">
                  <AlertTriangle className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-bold text-gray-900 mb-3">Hurricane Preparedness</h3>
                <p className="text-gray-600 mb-4">
                  Miami businesses face unique disaster recovery challenges during hurricane season. Our solutions ensure business continuity even during severe weather events.
                </p>
                <ul className="text-gray-600 text-sm space-y-2">
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Geo-redundant cloud backups outside hurricane zones</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Remote work enablement for evacuation scenarios</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Business continuity planning specific to tropical storms</span>
                  </li>
                </ul>
              </div>
              
              <div className="bg-white rounded-xl shadow-md p-8 hover:shadow-lg transition-all">
                <div className="bg-blue-100 w-16 h-16 rounded-full flex items-center justify-center mb-6">
                  <Globe className="h-8 w-8 text-blue-600" />
                </div>
                <h3 className="text-xl font-bold text-gray-900 mb-3">International Business</h3>
                <p className="text-gray-600 mb-4">
                  As a gateway to Latin America, Miami businesses need technology that supports international operations and multilingual environments.
                </p>
                <ul className="text-gray-600 text-sm space-y-2">
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Multilingual IT support (English/Spanish/Portuguese)</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>International communications infrastructure</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Cross-border data compliance expertise</span>
                  </li>
                </ul>
              </div>
              
              <div className="bg-white rounded-xl shadow-md p-8 hover:shadow-lg transition-all">
                <div className="bg-green-100 w-16 h-16 rounded-full flex items-center justify-center mb-6">
                  <Shield className="h-8 w-8 text-green-600" />
                </div>
                <h3 className="text-xl font-bold text-gray-900 mb-3">Regulatory Compliance</h3>
                <p className="text-gray-600 mb-4">
                  Miami's diverse industries face complex compliance requirements that demand specialized IT expertise and solutions.
                </p>
                <ul className="text-gray-600 text-sm space-y-2">
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>HIPAA compliance for healthcare providers</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>Financial regulations (SOX, FINRA, SEC)</span>
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-4 w-4 text-green-500 mr-2 mt-0.5 flex-shrink-0" />
                    <span>PCI DSS for retail and hospitality businesses</span>
                  </li>
                </ul>
              </div>
            </div>
          </div>
        </section>
      </section>

      {/* FAQ Section */}
      <section id="frequently-asked-questions" className="section-padding bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Serving All Miami-Dade Industries
            </h2>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto mb-12">
              Specialized IT solutions for South Florida's diverse business sectors
            </p>
            
            <div className="grid md:grid-cols-3 gap-8 mb-16">
              <div className="bg-gray-50 p-6 rounded-xl hover:shadow-md transition-all">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Healthcare</h3>
                <p className="text-gray-600 mb-4">HIPAA-compliant IT solutions for medical practices, clinics, and healthcare providers throughout Miami.</p>
                <ul className="text-gray-600 text-sm space-y-1">
                  <li>• Electronic medical records (EMR) support</li>
                  <li>• Patient data security and compliance</li>
                  <li>• Medical office IT infrastructure</li>
                </ul>
              </div>
              <div className="bg-gray-50 p-6 rounded-xl hover:shadow-md transition-all">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Financial Services</h3>
                <p className="text-gray-600 mb-4">Secure, compliant IT solutions for banks, investment firms, and financial services in Brickell and beyond.</p>
                <ul className="text-gray-600 text-sm space-y-1">
                  <li>• SOC 2 and FINRA compliance</li>
                  <li>• High-security infrastructure</li>
                  <li>• Financial data protection</li>
                </ul>
              </div>
              <div className="bg-gray-50 p-6 rounded-xl hover:shadow-md transition-all">
                <h3 className="text-xl font-bold text-gray-900 mb-3">Hospitality & Tourism</h3>
                <p className="text-gray-600 mb-4">Specialized IT for Miami's hotels, restaurants, and tourism businesses in South Beach and Miami Beach.</p>
                <ul className="text-gray-600 text-sm space-y-1">
                  <li>• POS and reservation systems</li>
                  <li>• Guest WiFi and network solutions</li>
                  <li>• 24/7 support for round-the-clock operations</li>
                </ul>
              </div>
            </div>
            
            <div className="flex items-center justify-center mb-4">
              <HelpCircle className="h-12 w-12 text-blue-600 mr-4" />
              <h2 className="text-3xl lg:text-4xl font-bold text-gray-900">
                Frequently Asked Questions
              </h2>
            </div>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto">
              Get answers to the most common questions Miami businesses ask about our IT services
            </p>
          </div>

          <div className="max-w-4xl mx-auto">
            <div className="grid md:grid-cols-1 gap-3">
              {faqs.map((faq, index) => (
                <div key={index} className="faq-item">
                  <button
                    onClick={() => toggleFAQ(index)}
                    className="faq-button"
                    aria-expanded={openFAQ === index}
                    aria-controls={`faq-answer-${index}`}>
                    <h3 className="text-base font-semibold text-gray-900 pr-4 text-left">
                      {faq.question}
                    </h3>
                    <div className="flex-shrink-0">
                      {openFAQ === index ? (
                        <Minus className="h-5 w-5 text-blue-600" />
                      ) : (
                        <Plus className="h-5 w-5 text-gray-400" />
                      )}
                    </div>
                  </button>
                  
                  {openFAQ === index && (
                    <div 
                      id={`faq-answer-${index}`}
                      className="faq-answer"
                    >
                      <div className="pt-4">
                        <p className="text-gray-700 leading-relaxed text-sm">
                          {faq.answer}
                        </p>
                      </div>
                    </div>
                  )}
                </div>
              ))}
            </div>

            {/* FAQ CTA */}
            <div className="mt-12 text-center bg-blue-50 rounded-2xl p-8">
              <h2 className="text-2xl font-bold text-gray-900 mb-4">
                Still Have Questions?
              </h2>
              <p className="text-gray-600 mb-6 max-w-2xl mx-auto">
                Our IT experts are here to help! Get personalized answers to your specific technology questions and learn how we can support your Miami business.
              </p>
              <div className="flex flex-col sm:flex-row gap-4 justify-center">
                <a 
                  href="tel:3058423363" 
                  className="bg-blue-600 text-white px-8 py-4 rounded-lg text-lg font-semibold hover:bg-blue-700 transition-all transform hover:scale-105 flex items-center justify-center shadow-lg"
                >
                  <Phone className="mr-2 h-5 w-5" />
                  Call (305) 842-3363
                </a>
                <a 
                  href="#contact" 
                  className="border-2 border-blue-600 text-blue-600 px-8 py-4 rounded-lg text-lg font-semibold hover:bg-blue-600 hover:text-white transition-all"
                >
                  Contact Us
                </a>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section id="get-started" className="cta-section">
        <div className="cta-content">
          <h2 className="cta-title">
            Ready to Transform Your Miami Business IT?
          </h2>
          <p className="cta-description">
            Join hundreds of Miami businesses from Homestead to Aventura who trust us with their technology. Get your free consultation today and discover how our local IT expertise can benefit your South Florida business.
          </p>
          <div className="cta-buttons">
            <a href="tel:3058423363" className="bg-white text-blue-600 px-8 py-4 rounded-lg text-lg font-semibold hover:bg-gray-100 transition-all transform hover:scale-105 flex items-center justify-center">
              <Phone className="mr-2 h-5 w-5" />
              Call (305) 842-3363
            </a>
            <a href="#contact" className="border-2 border-white text-white px-8 py-4 rounded-lg text-lg font-semibold hover:bg-white hover:text-blue-600 transition-all">
              Contact Us
            </a>
          </div>
        </div>
      </section>

      {/* Contact Section */}
      <section id="contact" className="section-padding bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Get In Touch Today
            </h2>
            <p className="text-xl text-gray-600 mb-4">
              Ready to discuss your Miami business IT needs? We're here to help.
            </p>
            <p className="text-lg text-gray-600">
              Our local team of IT experts serves all of Miami-Dade County with personalized technology solutions. Whether you need cybersecurity, cloud services, or complete managed IT support, we're just a call or message away.
            </p>
          </div>

          <div className="grid lg:grid-cols-2 gap-12">
            <div>
              <h3 className="text-2xl font-bold text-gray-900 mb-6">Contact Information</h3>
              <div className="space-y-6">
                <div className="flex items-center">
                  <Phone className="h-6 w-6 text-blue-600 mr-4" />
                  <div>
                    <div className="font-semibold text-gray-900">
                      <a href="tel:3058423363" className="hover:text-blue-600 transition-colors">
                        (305) 842-3363
                      </a>
                    </div>
                    <div className="text-gray-600">Support Available</div>
                  </div>
                </div>
                <div className="flex items-center">
                  <Mail className="h-6 w-6 text-blue-600 mr-4" />
                  <div>
                    <div className="font-semibold text-gray-900">info@manageditservicesmiamifl.com</div>
                    <div className="text-gray-600">General inquiries</div>
                  </div>
                </div>
                <div className="flex items-start">
                  <MapPin className="h-6 w-6 text-blue-600 mr-4 mt-1" />
                  <div>
                    <div className="font-semibold text-gray-900">Miami, FL 33131</div>
                    <div className="text-gray-600">Serving all Miami-Dade County including:</div>
                    <div className="flex flex-wrap gap-1 mt-2">
                      {["Brickell", "Downtown", "Coral Gables", "Doral", "Aventura", "South Beach", "Kendall", "Hialeah", "Miami Lakes", "Homestead", "Pinecrest", "Wynwood", "Miami Beach", "Coconut Grove"].map((area, index) => (
                        <span key={index} className="bg-blue-100 text-blue-800 px-2 py-0.5 rounded-full text-xs">
                          {area}
                        </span>
                      ))}
                    </div>
                  </div>
                </div>
              </div>

              <div className="mt-8">
                <h4 className="text-lg font-semibold text-gray-900 mb-4">Office Hours</h4>
                <div className="text-gray-600 space-y-1">
                  <div>Monday - Friday: 8:00 AM - 6:00 PM</div>
                  <div>Saturday: 9:00 AM - 2:00 PM</div>
                  <div>Sunday: Emergency support only</div>
                  <div className="font-semibold text-blue-600 mt-2">Emergency Support Available</div>
                </div>
              </div>
            </div>

            <div className="bg-gray-50 rounded-xl p-8">
              <h3 className="text-2xl font-bold text-gray-900 mb-6">Send Us a Message</h3>
              <form onSubmit={handleSubmit} className="space-y-6">
                <div className="grid md:grid-cols-2 gap-4">
                  <input
                    type="text"
                    name="name"
                    placeholder="Your Name"
                    value={formData.name}
                    onChange={handleInputChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                  <input
                    type="email"
                    name="email"
                    placeholder="Email Address"
                    value={formData.email}
                    onChange={handleInputChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    required
                  />
                </div>
                <input
                  type="tel"
                  name="phone"
                  placeholder="Phone Number"
                  value={formData.phone}
                  onChange={handleInputChange}
                  className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                  required
                />
                <textarea
                  name="message"
                  rows={4}
                  placeholder="Tell us about your IT needs..."
                  value={formData.message}
                  onChange={handleInputChange}
                  className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                  required
                ></textarea>
                <button
                  type="submit"
                  className="w-full bg-blue-600 text-white py-3 rounded-lg font-semibold hover:bg-blue-700 transition-colors flex items-center justify-center"
                >
                  Send Message <ArrowRight className="ml-2 h-5 w-5" />
                </button>
              </form>
            </div>
          </div>
        </div>
      </section>
    </>
  );
}